@@ -12,27 +12,28 @@ async def make_request(url, payload, headers=None):
             return response.json()       # or just return response if you want the full object
 
 
-
+def get_kwargs_bools(key,bools,**kwargs):
+    bools[key]= kwargs.get(key)
+    if key in kwargs:
+        del kwargs[key]
+    return bools,kwargs
 def get_solcatcherSettings(getApi=False,**kwargs):
-    solcatcherSettings = kwargs.get('solcatcherSettings')
-    if 'solcatcherSettings' in kwargs:
-        del kwargs['solcatcherSettings']
-    headers = kwargs.get('headers')
-    if 'headers' in kwargs:
-        del kwargs['headers']
-    headers = headers or get_headers()
-    apiKey = kwargs.get('solcatcherApiKey')
-    if 'solcatcherApiKey' in kwargs:
-        del kwargs['solcatcherApiKey']
+    bools = {}
+    bools,kwargs = get_kwargs_bools(key='solcatcherSettings',bools=bools,**kwargs)
+    bools,kwargs = get_kwargs_bools(key='headers',bools=bools,**kwargs)
+    headers = bools.get('headers',get_headers())
+    bools,kwargs = get_kwargs_bools(key='solcatcherApiKey',bools=bools,**kwargs)
     if apiKey or getApi:
         apiKey = apiKey or getApi
         if isinstance(apiKey,bool):
             apiKey=None
         headers = get_db_header(headers=headers,api_key=apiKey)
-    headers = headers or  get_headers()
-    return kwargs,solcatcherSettings,headers
+    headers = bools.get('headers',headers) or get_headers()
+    return kwargs,solcatcherSettings,headers,bools
 def runSolcatcherSettings(response,solcatcherSettings):
     usedKeys = []
+    status_code = response.status_code
+    
     if solcatcherSettings:
         for key,value in solcatcherSettings.items():
             if key == 'getResponse':
@@ -48,10 +49,14 @@ def runSolcatcherSettings(response,solcatcherSettings):
                         result = result.get(value)
                 response = result
                 usedKeys.append(key)
+            if key == 'getStatusCode':
+                get_status_code = value
+    if get_status_code:
+        return {"result" = response,"status_code":status_code}
     return response
 
 async def async_call_solcatcher_ts(endpoint,*args,**kwargs):
-    kwargs,solcatcherSettings,headers = get_solcatcherSettings(**kwargs)
+    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
     payload = get_payload(*args,**kwargs)
     url = getSolcatcherTsUrl(endpoint=endpoint)
     response = await  make_request(url, payload,headers=headers)
@@ -59,7 +64,7 @@ async def async_call_solcatcher_ts(endpoint,*args,**kwargs):
     return result
 
 async def async_call_solcatcher_py(endpoint,*args,**kwargs):
-    kwargs,solcatcherSettings,headers = get_solcatcherSettings(**kwargs)
+    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
     payload = get_payload(*args,**kwargs)
     url = getSolcatcherPairCatchUrl(endpoint=endpoint)
     response = await  make_request(url, payload,headers=headers)
@@ -67,7 +72,7 @@ async def async_call_solcatcher_py(endpoint,*args,**kwargs):
     return result
 
 async def async_call_solcatcher_db(endpoint,*args,**kwargs):
-    kwargs,solcatcherSettings,headers = get_solcatcherSettings(True,**kwargs)
+    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(True,**kwargs)
     payload = get_payload(*args,**kwargs)
     url = getSolcatcherDbCalls(endpoint=endpoint)
     response = await  make_request(url, payload,headers=headers)
@@ -99,7 +104,10 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
     After the 1st attempt, set url_1_only=False.
     """
-    kwargs,solcatcherSettings,headers = get_solcatcherSettings(**kwargs)
+    solcatcherSettings={"getStatusCode":True}
+    solcatcherSettings.update(kwargs.get('solcatcherSettings',{}))
+    kwargs['solcatcherSettings']=solcatcherSettings
+    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
     for attempt in range(3):  # Retry logic
         if attempt == 2:
             url_2_only = True
@@ -116,8 +124,18 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
             headers = headers,
             **kwargs
         )
-        if response:
-            return response
+        result = runSolcatcherSettings(response,solcatcherSettings)
+        if bools.get('getStatusCode'):
+            if isinstance(result,dict):
+                status_code = response.get('status_code')
+                if status_code and status_code != 429:
+                    if bools.get('getResult'):
+                        result = result.get('result',response)
+                    return result
+            if bools.get('getResult'):
+                result = result.get('result',response)
+        elif result:
+            return result
     # If no response after all attempts, return empty or raise an exception
     return []
 
@@ -136,5 +154,3 @@ def call_solcatcher_ts(endpoint,*args,**kwargs):
 def call_solcatcher_db(endpoint,*args, **kwargs):
     return asyncio.run(async_call_solcatcher_db(endpoint,*args,**kwargs))
 
-result = call_solcatcher_py('get-genesis-signature',params=['HY5y5jS1it6SLgE8GGmomPbm3MEabpxdD1jPidKaTmjK'])
-input(result)
